@@ -1,3 +1,5 @@
+import Foundation
+
 class SwiftString {
     var string: String
 
@@ -24,37 +26,21 @@ class SwiftString {
 
 extension RustString {
     func toString() -> String {
-        // We prevent the RustString from getting dropped until we've cloned the memory
-        // into a Swift String
-        let opaque = Unmanaged.passRetained(self)
-
         let str = self.as_str()
         let string = str.toString()
 
-        let _ = opaque.takeRetainedValue()
-
         return string
     }
 }
 
 extension RustStr {
     func toBufferPointer() -> UnsafeBufferPointer<UInt8> {
-        UnsafeBufferPointer(start: self.start, count: Int(self.len))
+        let bytes = UnsafeBufferPointer(start: self.start, count: Int(self.len))
+        return bytes
     }
 
     func toString() -> String {
-        String(bytes: self.toBufferPointer(), encoding: .utf8)!
-    }
-}
-
-import Foundation
-extension String {
-    func toRustStr() -> RustStr {
-        // TODO: Does the utf8String have the same lifetime as our String?
-        //  If not this can lead to undefined behavior..
-        let ptr = UnsafeMutableRawPointer(mutating: (self as NSString).utf8String)!
-        let start = ptr.assumingMemoryBound(to: UInt8.self)
-        let len = UInt(self.count)
-        return RustStr(start: start, len: len)
+        let bytes = self.toBufferPointer()
+        return String(bytes: bytes, encoding: .utf8)!
     }
 }
\ No newline at end of file
